@@ -35,6 +35,11 @@
   CNRead/MNRead.listObjects()
   CNAuthorization/MNAuthorization.isAuthorized()
   CNCore/MNCore.ping()
+
+  See the `Coordinating Node <http://mule1.dataone.org/ArchitectureDocs-current/apis/CN_APIs.html>`_
+  and `Member Node <http://mule1.dataone.org/ArchitectureDocs-current/apis/MN_APIs.html>`_
+  APIs for details on how to use the methods in this class.
+
 :Created: 2011-01-20
 :Author: DataONE (Vieglais, Dahl)
 '''
@@ -300,20 +305,9 @@ class DataONEBaseClient(d1_common.restclient.RESTClient):
     if self._status_is_200_ok(response):
       self._read_and_capture(response)
       return headers
-    self._raise_dataone_exception_from_header(response, headers)
+    raise d1_common.types.exceptions.deserialize_from_headers(headers)
 
 
-  def _raise_dataone_exception_from_header(self, response, headers):
-    error_code = response.status
-    detail_code = 0;
-    description = headers.get('dataone-exception-description',
-                              '<unknown error>')
-    trace_information = None
-    pid = headers.get('dataone-exception-pid', '<unknown pid>')
-
-    raise d1_common.types.exceptions.DataONEIdentifierException(error_code,
-      detail_code, description, trace_information, pid)
-
   # ----------------------------------------------------------------------------
   # Misc.
   # ----------------------------------------------------------------------------
@@ -325,13 +319,13 @@ class DataONEBaseClient(d1_common.restclient.RESTClient):
       if start < 0 or count < 0:
         raise ValueError
     except ValueError:
-      raise d1_common.types.exceptions.InvalidRequest(10002,
+      raise d1_common.types.exceptions.InvalidRequest(0,
         "'start' and 'count' must be 0 or a positive integer")
 
 
   def _date_span_sanity_check(self, fromDate, toDate):
     if toDate is not None and fromDate is not None and fromDate > toDate:
-      raise d1_common.types.exceptions.InvalidRequest(10002,
+      raise d1_common.types.exceptions.InvalidRequest(0,
         'Ending date is before starting date')
 
 
@@ -423,10 +417,7 @@ class DataONEBaseClient(d1_common.restclient.RESTClient):
     '''
     try:
       response = self.pingResponse(vendorSpecific=vendorSpecific)
-      if self._status_is_200_ok(response):
-        return True
-      else:
-        return False
+      return self._read_boolean_response(response)
     except:
       return False
 
@@ -519,7 +510,7 @@ class DataONEBaseClient(d1_common.restclient.RESTClient):
     query = {
       'fromDate': fromDate,
       'toDate': toDate,
-      'objectFormat': objectFormat,
+      'formatId': objectFormat,
       'replicaStatus': replicaStatus,
       'start': int(start),
       'count': int(count)
