@@ -46,6 +46,7 @@
 import codecs
 import datetime
 import hashlib
+import logging
 import os
 import sys
 import pprint
@@ -61,6 +62,9 @@ import d1_client.mnclient
 
 
 def main():
+  logging.basicConfig()
+  logging.getLogger('').setLevel(logging.DEBUG)
+
   # Connect to the DataONE Coordinating Nodes in the default (production) environment.
   c = d1_client.solr_client.SolrConnection()
 
