@@ -58,10 +58,11 @@ class TestSolrClient(TestCaseWithURLCompare):
     for row in rows:
       if row:
         return
-    self.assertTrue(False)
+    self.assertTrue(False, 'Expected at least one row in results')
 
 
   def test_100(self):
+    '''SOLRSearchResponseIterator()'''
     # Orig host, solrBase:
     #client = solr_client.SolrConnection(host="cn-dev-unm-1.test.dataone.org", solrBase="/solr/d1-cn-index")
 
@@ -81,6 +82,7 @@ class TestSolrClient(TestCaseWithURLCompare):
 
 
   def test_110(self):
+    '''SOLRArrayResponseIterator()'''
     client = solr_client.SolrConnection(host=self.options.query_base_url,
                                         solrBase=self.options.query_endpoint)
     q = '*:*'
@@ -93,6 +95,7 @@ class TestSolrClient(TestCaseWithURLCompare):
 
 
   def test_200(self):
+    '''SOLRValuesResponseIterator()'''
     client = solr_client.SolrConnection(host=self.options.query_base_url,
                                         solrBase=self.options.query_endpoint)
     q = '*:*'
@@ -107,7 +110,8 @@ class TestSolrClient(TestCaseWithURLCompare):
   # Disabled because listFields is based on the Solr Luke handler, which we
   # D1 doesn't expose. Instead, use CNRead.getQueryEngineDescription() D1 API to
   # get the list of fields.
-  def _test_300_listFields(self):
+  def _test_300(self):
+    '''listFields()'''
     client = solr_client.SolrConnection(host=self.options.query_base_url,
                                         solrBase=self.options.query_endpoint)
     flds = client.getFields()
@@ -116,13 +120,6 @@ class TestSolrClient(TestCaseWithURLCompare):
       fld = flds['fields'][name]
       print "%s (%s) %d / %d" % (name, fld['type'], fld['distinct'], fld['docs'])
 
-
-  def test_400(self):
-    client = solr_client.SolrConnection(host=self.options.query_base_url,
-                                        solrBase=self.options.query_endpoint)
-    results = solr_client.SOLRSearchResponseIterator(client, 'id:[* TO *]')
-    self._assert_at_least_one_row_populated(results)
-
 #===============================================================================
 
 def log_setup():
@@ -141,9 +138,9 @@ def main():
   # Command line opts.
   parser = optparse.OptionParser()
   parser.add_option('--query-host-url', dest='query_base_url', action='store',
-                    type='string', default='cn-dev-unm-1.test.dataone.org')
+                    type='string', default='cn.dataone.org')
   parser.add_option('--query-base-url', dest='query_endpoint', action='store',
-                    type='string', default='/cn/v1/query/solr/?q=*:*')
+                    type='string', default='/cn/v1/query/solr/')
   parser.add_option('--debug', action='store_true', default=False, dest='debug')
   parser.add_option('--test', action='store', default='', dest='test',
                     help='run a single test')
@@ -167,5 +164,4 @@ def main():
 
 
 if __name__ == '__main__':
-  print 'See ticket #4110'
-  #main()
+  main()
